<?php
$page_title = "Risk口座一覧";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					<div class="btns">
						<input type="button" id="btnSearchAll" name="btnSearchAll" value="すべて" class="btn bg-default px50 hi22">&nbsp;
						<input type="button" id="btnSearch" value="検索" class="btn bg-default px50 hi22">
					</div>
				</div>
				<form id="searchForm" action="" method="post">
					<table class="conditions fontS w100p">
						<colgroup>
							<col class="w40p">
							<col class="w60p">
						</colgroup>
						<tr>
							<th>名前</th>
							<td><input type="text" id="name" name="name" value="<?php $this -> echoName(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<th>口座番号</th>
							<td><input type="text" id="user_account" name="user_account" value="<?php $this -> echoAccountNumber(); ?>" class="w100p"></td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">状態</span>
								<?php $this -> dispStatuses(); ?>
							</td>
						</tr>
						<tr>
							<td colspan="2">
								<span class="th">口座タグ日</span>
								<?php $this -> dispOpenFlg(); ?>
								<input type="text" id="tag_from" name="tag_from" value="<?php $this -> echoTagFrom(); ?>" class="px110"> - <input type="text" id="tag_to" name="tag_to" value="<?php $this -> echoTagTo(); ?>" class="px110">
							</td>
						</tr>
					</table>
					<input type="hidden" value="search" id="type_search" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<?php $this -> dispPager(); ?>
						</div>
						<?php // $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th class="w3p">口座番号</th>
									<th class="w7p">名前</th>
									<th class="w3p">審査状況</th>
									<th class="w3p">リスクレベル</th>
									<th class="w10p">理由</th>
									<th class="w5p">タグした日付</th>
								</tr>
								<?php $this -> echoList(); ?>
							</table>
							<input type="hidden" value="account_edit" id="action" name="action" />
							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" id="detail_account" name="detail_account" />
						</form>
						<div class="article-bottom">
							<?php  $this -> dispPager(); ?>
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="js/account_list.js"></script>
</body>
</html>
